package com.example.netwrok_datastore

import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.activity.enableEdgeToEdge
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.padding
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Modifier
import androidx.compose.ui.tooling.preview.Preview
import androidx.navigation.compose.NavHost
import androidx.navigation.compose.composable
import androidx.navigation.compose.rememberNavController
import com.example.netwrok_datastore.data.AuthRepository
import com.example.netwrok_datastore.data.local.LocalStorage
import com.example.netwrok_datastore.data.remote.RetrofitSettings
import com.example.netwrok_datastore.domain.usecase.AuthUseCase
import com.example.netwrok_datastore.ui.screen.ProfileScreen
import com.example.netwrok_datastore.ui.screen.SplashScreen
import com.example.netwrok_datastore.ui.screen.registration.RegistrationScreen
import com.example.netwrok_datastore.ui.screen.registration.RegistrationViewModel
import com.example.netwrok_datastore.ui.theme.NetwrokDatastoreTheme
import kotlinx.serialization.Serializable
import org.koin.androidx.viewmodel.ext.android.viewModel

class MainActivity : ComponentActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        enableEdgeToEdge()

        val authRepository = AuthRepository(RetrofitSettings.authApi)
        val localStorage = LocalStorage(applicationContext)
        val authUseCase = AuthUseCase(localStorage, authRepository)

        val registrationViewModel: RegistrationViewModel by viewModel()
        setContent {
            val navController = rememberNavController()
            NetwrokDatastoreTheme {
                NavHost(navController, startDestination = SplashScreen){
                    composable<SplashScreen> {
                        SplashScreen(
                            authUseCase = authUseCase,
                            onNavigationToProfileScreen = {
                                navController.navigate(route = Profile)
                            }
                        ){
                            navController.navigate(route = Registration)
                        }
                    }
                    composable<Registration> {
                        RegistrationScreen(registrationViewModel){
                            navController.navigate(route = Profile)
                        }
                    }
                    composable<Profile> {
                        ProfileScreen()
                    }
                }
            }
        }
    }
}

@Serializable
object SplashScreen
@Serializable
object Registration
@Serializable
object Profile

