package com.example.netwrok_datastore.domain.usecase

import com.example.netwrok_datastore.data.AuthRepository
import com.example.netwrok_datastore.data.local.LocalStorage
import com.example.netwrok_datastore.data.remote.NetworkResponse
import com.example.netwrok_datastore.data.remote.dto.request.RegistrationRequest
import kotlinx.coroutines.flow.Flow
import kotlinx.coroutines.flow.flow

class AuthUseCase(private val localStorage: LocalStorage,
                  private val authRepository: AuthRepository) {
    val token: Flow<String> = localStorage.tokenFlow
   suspend fun registration(registrationRequest: RegistrationRequest): Flow<NetworkResponse> = flow{
         try {
             emit(NetworkResponse.Loading)
            val result = authRepository.registration(registrationRequest)
            localStorage.setToken(result.second)
            emit(NetworkResponse.Success(result))
        }
        catch (e: Exception){
            e.message?.let {
                emit(NetworkResponse.Error(it))
                return@flow
            }
            emit(NetworkResponse.Error("Unknown Error"))
        }
    }
}