package com.example.netwrok_datastore.ui.screen.registration

import android.window.SplashScreen
import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.padding
import androidx.compose.material3.Button
import androidx.compose.material3.CircularProgressIndicator
import androidx.compose.material3.OutlinedTextField
import androidx.compose.material3.Scaffold
import androidx.compose.material3.SnackbarHost
import androidx.compose.material3.SnackbarHostState
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.remember
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.res.colorResource
import androidx.compose.ui.res.painterResource
import androidx.lifecycle.viewmodel.compose.viewModel
import androidx.lifecycle.viewmodel.viewModelFactory
import com.example.netwrok_datastore.R
import com.example.netwrok_datastore.Registration
import com.example.netwrok_datastore.domain.usecase.AuthUseCase
import kotlinx.coroutines.delay
import kotlinx.coroutines.runBlocking

@Composable
fun RegistrationScreen(viewModel: RegistrationViewModel, onNavigationToProfile: ()-> Unit){
    val snackBarHostState = remember { SnackbarHostState() }

    Scaffold(
        snackbarHost = { SnackbarHost(snackBarHostState) }
    ) { paddingValues ->
        Column(
            modifier = Modifier
                .padding(paddingValues)
                .fillMaxSize()
                .background(Color.White),
            horizontalAlignment = Alignment.CenterHorizontally,
            verticalArrangement = Arrangement.Center
        ) {
            val registrationScreenState = viewModel.registrationScreenState
            LaunchedEffect(registrationScreenState.value.isSignIn) {
                if (registrationScreenState.value.isSignIn) {
                    onNavigationToProfile()
                }
            }
            LaunchedEffect(registrationScreenState.value.errorMessage) {
                registrationScreenState.value.errorMessage?.let {
                    snackBarHostState.showSnackbar(it)
                }
            }
            OutlinedTextField(
                value = registrationScreenState.value.fio,
                onValueChange = { viewModel.setFio(it) }
            )
            OutlinedTextField(
                value = registrationScreenState.value.email,
                onValueChange = { viewModel.setEmail(it) }
            )
            OutlinedTextField(
                value = registrationScreenState.value.password,
                onValueChange = { viewModel.setPassword(it) }
            )
            Button(onClick = {
                viewModel.registration()
            }) {
                Text(text = "Registration")
                if(registrationScreenState.value.isLoading) CircularProgressIndicator(color = Color.White)
            }
        }
    }
}