package com.example.netwrok_datastore.ui.screen.registration

import androidx.compose.runtime.mutableStateOf
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import com.example.netwrok_datastore.data.remote.NetworkResponse
import com.example.netwrok_datastore.data.remote.dto.request.RegistrationRequest
import com.example.netwrok_datastore.domain.usecase.AuthUseCase
import kotlinx.coroutines.delay
import kotlinx.coroutines.launch

class RegistrationViewModel(val authUseCase: AuthUseCase): ViewModel() {
    val registrationScreenState = mutableStateOf(RegistrationScreenState())
    fun setEmail(email: String){
        registrationScreenState.value = registrationScreenState.value.copy(email = email)
    }
    fun setPassword(password: String){
        registrationScreenState.value = registrationScreenState.value.copy(password = password)
    }
    fun setFio(fio: String){
        registrationScreenState.value = registrationScreenState.value.copy(fio = fio)
    }
    private fun setErrorMessage(message: String){
        registrationScreenState.value = registrationScreenState.value.copy(errorMessage = message)
    }
    private fun setLoading(isLoading: Boolean){
        registrationScreenState.value = registrationScreenState.value.copy(isLoading = isLoading)
    }
    fun registration(){
        viewModelScope.launch {
            val registrationRequest = RegistrationRequest(
                email = registrationScreenState.value.email,
                userName = registrationScreenState.value.fio,
                password = registrationScreenState.value.password
            )
            val result = authUseCase.registration(registrationRequest)
            result.collect{ it ->
                when(it){
                    is NetworkResponse.Error -> {
                        setLoading(false)
                        setErrorMessage(it.errorMessage)
                    }
                    is NetworkResponse.Success<*> -> {
                        setLoading(false)
                        registrationScreenState.value = registrationScreenState.value.copy(isSignIn = true)
                    }
                    is NetworkResponse.Loading -> {
                        setLoading(true)
                    }
                }
            }
        }
    }
}